@@ -8,6 +8,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 require AutoLoader;
+require Digest::MD5;
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -19,7 +20,7 @@ require AutoLoader;
    NameSpace_URL
    NameSpace_X500
 );
-$VERSION = '0.148';
+$VERSION = '1.200_01';
 
 # Preloaded methods go here.
 
@@ -176,7 +177,7 @@ The module allows exporting of several standard namespace UUIDs:
  
 =head1 AUTHOR
 
-Alexander Golomshtok<agolomsh@cpan.org>
+Alexander Golomshtok <agolomsh@cpan.org>
 
 =head1 SEE ALSO
 
